@@ -97,4 +97,64 @@ def SearchJetBrains(query):
 def SearchQuora(query):
   query = query.replace(" ", "%20")
   query_URL = "https://www.quora.com/search?q=" + query
-  return query_URL
\ No newline at end of file
+  return query_URL
+
+def SearchUrbanDictionary(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.urbandictionary.com/define.php?term=" + query
+  return query_URL
+
+def SearchReddit(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.reddit.com/search/?q=" + query
+  return query_URL
+
+def SearchLenovo(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.lenovo.com/us/en/search?fq=&text=" + query
+  return query_URL
+
+def SearchInstantGaming(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.instant-gaming.com/en/search/?query=" + query
+  return query_URL
+
+def SearchTextures(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.textures.com/search?q=" + query
+  return query_URL
+
+def SearchCrunchyroll(query, beta=True):
+  query = query.replace(" ", "+")
+  query_URL = "https://www.crunchyroll.com/search?from=&q=" + query
+
+  if beta:
+    query = query.replace("+", "%20")
+    query_URL = "https://beta.crunchyroll.com/search?q=" + query
+
+  return query_URL
+
+def SearchLinkedIn(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.linkedin.com/search/results/all/?keywords=" + query
+  return query_URL
+
+def SearchChromeWebStore(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://chrome.google.com/webstore/search/" + query
+  return query_URL
+
+def SearchOperaAddons(query):
+  query = query.replace(" ", "+")
+  query_URL = "https://addons.opera.com/de/search/?query=" + query
+  return query_URL
+
+def SearchMmoga(query):
+  query = query.replace(" ", "+")
+  query_URL = "https://www.mmoga.com/advanced_search.php?keywords=" + query
+  return query_URL
+
+def SearchFacebook(query):
+  query = query.replace(" ", "%20")
+  query_URL = "https://www.facebook.com/search/top?q=" + query
+  return query_URL
